#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8

NAME = 'drove'
VERSION = '0.2'
DESCRIPTION = 'Monitoring and statistical analysis ' + \
              'system for a drove of systems'
AUTHOR_NAME = 'Andrés J. Díaz'
AUTHOR_EMAIL = 'ajdiaz@connectical.com'
URL = 'http://drove.io'
LICENSE = 'GPL3'

CLIENT_NAME = 'drop'
CLIENT_VERSION = VERSION
CLIENT_DESCRIPTION = 'drop is a tool to install drove.io plugins easily'
